function [area sens spe]=area_under_roc(values,labels,plot_it,color)

%%
% Before running this code, you need install Matlab
% In our experiment, Matlab R2014a 64bit is tested
%
% COMPUTE AUC
% This function computes the area under the ROC curve given a real
% "values" vector and a boolean "labels" vector.
%
% INPUTS: values (vector of predictions), labels (vector of labels, same
% size as values), plot_it (boolean, see description, default=0), color
% (string such as 'b', '*r', etc.)
%
% OUTPUTS: area (AUC), sens and spe (sensitivities and specificities,
% useful to plot the curve)
%
%%

if nargin<3
    plot_it=0;
end

values=(values-min(values))/(max(values)-min(values));
[values idx]=sort(values);
labels=labels(idx);
labels(labels==-1)=0;

m=length(values);
n=1000;
sens=zeros(n,1);
spe=zeros(n,1);

threshold=0;
for i=1:n
    threshold=threshold+0.001;
    labtmp=ones(m,1);
    labtmp(values<threshold)=0;
    sens(i)=sum(labtmp==1 & labels==1)/sum(labels==1);
    spe(i)=sum(labtmp==0 & labels==0)/sum(labels==0);
end

sens(n+1)=0;
spe(n+1)=1;

area=0;
for i=1:n-1
    area=area + (sens(i)+sens(i+1))/2*(spe(i+1)-spe(i));
end


if 1
    spe;
    sens;
    plot(1-spe,sens,'linewidth',3);
end


